# This folder contains processed binary knapsack files available in [Michigan Technological University domain](https://pages.mtu.edu/~kreher/cages/Data.html)

Any binary knapsack problem contains four very important characteristics:
* Number of items
* Weight of each item
* Value of each item
* Maximum allowable weight

The ultimate **goal** is to find the items resulting into the maximum accumulated value subject to the constraint of maximum weight.<br>
More detailed analysis of the binary knapsack problem can be found in this [tutorialspoint link](https://www.tutorialspoint.com/design_and_analysis_of_algorithms/design_and_analysis_of_algorithms_01_knapsack.htm).

There is also a basic python code attached to this repo for extracting the data properly.<br>
Use **knapsack_data_extractor.py** for this purpose.<br>
***The code is quite self-explanatory***
